@@ -1085,6 +1085,7 @@ def handle_spoke_local_portfolios(
                     account_id=task_to_add.get("account_id"),
                     region=task_to_add.get("region"),
                     task_reference=share_and_accept_ref,
+                    share_tag_options=task_to_add.get("share_tag_options"),
                     dependencies_by_reference=[
                         hub_portfolio_ref,
                         constants.CREATE_POLICIES,
@@ -1370,6 +1371,7 @@ def handle_launches(
                 puppet_account_id=puppet_account_id,
                 account_id=task_to_add.get("account_id"),
                 region=task_to_add.get("region"),
+                share_tag_options=task_to_add.get("share_tag_options"),
                 task_reference=share_and_accept_ref,
                 dependencies_by_reference=[
                     hub_portfolio_ref,
@@ -1686,7 +1688,7 @@ def deploy_from_task_reference(path):
 
     executor_account_id = config.get_executor_account_id()
     is_dry_run = is_list_launches = False
-    execution_mode = "hub"
+    execution_mode = config.get_execution_mode()
     on_complete_url = config.get_on_complete_url()
     running_exploded = False
     output_cache_starting_point = ""
